package com.ruoyi.project.training.bccnew.controller;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.framework.web.page.TableDataInfo;
import com.ruoyi.project.approve.damain.DevTask;
import com.ruoyi.project.training.bccnew.domain.TTsApprove;
import com.ruoyi.project.training.bccnew.service.ITTsApproveService;
import com.ruoyi.project.training.bccnew.service.ITTsNewService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 导师带徒审批Controller
 *
 * @author ssy
 * @date 2024-06-25
 */
@RestController
@RequestMapping("/bccnew/approve")
public class TTsApproveController extends BaseController {
    @Autowired
    private ITTsApproveService tTsApproveService;
    @Autowired
    private ITTsNewService tTsNewService;

    /**
     * 查询导师带徒审批列表
     */
    @PreAuthorize("@ss.hasPermi('bccnew:approve:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTsApprove tTsApprove) {
        startPage();
        List<TTsApprove> list = tTsApproveService.selectTTsApproveList(tTsApprove);
        return getDataTable(list);
    }

    /**
     * 导出导师带徒审批列表
     */
    @PreAuthorize("@ss.hasPermi('bccnew:approve:export')")
    @Log(title = "导师带徒审批", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TTsApprove tTsApprove) {
        List<TTsApprove> list = tTsApproveService.selectTTsApproveList(tTsApprove);
        ExcelUtil<TTsApprove> util = new ExcelUtil<TTsApprove>(TTsApprove.class);
        return util.exportExcel(list, "approve");
    }

    /**
     * 获取导师带徒审批详细信息
     */
//    @PreAuthorize("@ss.hasPermi('bccnew:approve:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        TTsApprove tTsApprove = tTsApproveService.selectTTsApproveById(id);
        tTsApprove.settTsNew(tTsNewService.selectTTsNewById(tTsApprove.getTrainingId()));
        return AjaxResult.success(tTsApprove);
    }

    /**
     * 新增导师带徒审批
     */
    @PreAuthorize("@ss.hasPermi('bccnew:approve:add')")
    @Log(title = "导师带徒审批", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTsApprove tTsApprove) {
        return toAjax(tTsApproveService.insertTTsApprove(tTsApprove));
    }

    /**
     * 修改导师带徒审批
     */
    @PreAuthorize("@ss.hasPermi('bccnew:approve:edit')")
    @Log(title = "导师带徒审批", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTsApprove tTsApprove) {
        return toAjax(tTsApproveService.updateTTsApprove(tTsApprove));
    }

    @Log(title = "导师带徒审批", businessType = BusinessType.UPDATE)
    @PutMapping("/handle")
    public AjaxResult handle(@RequestBody DevTask devTask) {
        return tTsApproveService.handle(devTask, getNickName(), getUserId().toString());
    }

    /**
     * 删除导师带徒审批
     */
    @PreAuthorize("@ss.hasPermi('bccnew:approve:remove')")
    @Log(title = "导师带徒审批", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tTsApproveService.deleteTTsApproveByIds(ids));
    }
}
