package com.ruoyi.project.training.bccnew.controller;

import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.config.RuoYiConfig;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.framework.web.page.TableDataInfo;
import com.ruoyi.project.ehs.domain.TRcfile;
import com.ruoyi.project.training.bccnew.domain.TTsFirstplanTmpl;
import com.ruoyi.project.training.bccnew.service.ITTsFirstplanTmplService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.List;

/**
 * 进组培训模版Controller
 *
 * @author ssy
 * @date 2024-05-22
 */
@RestController
@RequestMapping("/bccnew/firstPlanTmpl")
public class TTsFirstplanTmplController extends BaseController {
    @Autowired
    private ITTsFirstplanTmplService tTsFirstplanTmplService;

    /**
     * 查询进组培训模版列表
     */
    @PreAuthorize("@ss.hasPermi('bccnew:firstPlanTmpl:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTsFirstplanTmpl tTsFirstplanTmpl) {
        startPage();
        List<TTsFirstplanTmpl> list = tTsFirstplanTmplService.selectTTsFirstplanTmplList(tTsFirstplanTmpl);
        return getDataTable(list);
    }

    /**
     * 导出进组培训模版列表
     */
    @PreAuthorize("@ss.hasPermi('bccnew:firstPlanTmpl:export')")
    @Log(title = "进组培训模版", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TTsFirstplanTmpl tTsFirstplanTmpl) {
        List<TTsFirstplanTmpl> list = tTsFirstplanTmplService.selectTTsFirstplanTmplList(tTsFirstplanTmpl);
        ExcelUtil<TTsFirstplanTmpl> util = new ExcelUtil<TTsFirstplanTmpl>(TTsFirstplanTmpl.class);
        return util.exportExcel(list, "firstPlanTmpl");
    }

    /**
     * 获取进组培训模版详细信息
     */
    @PreAuthorize("@ss.hasPermi('bccnew:firstPlanTmpl:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(tTsFirstplanTmplService.selectTTsFirstplanTmplById(id));
    }

    /**
     * 新增进组培训模版
     */
    @PreAuthorize("@ss.hasPermi('bccnew:firstPlanTmpl:add')")
    @Log(title = "进组培训模版", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTsFirstplanTmpl tTsFirstplanTmpl) {
        return toAjax(tTsFirstplanTmplService.insertTTsFirstplanTmpl(tTsFirstplanTmpl));
    }

    /**
     * 修改进组培训模版
     */
    @PreAuthorize("@ss.hasPermi('bccnew:firstPlanTmpl:edit')")
    @Log(title = "进组培训模版", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTsFirstplanTmpl tTsFirstplanTmpl) {
        return toAjax(tTsFirstplanTmplService.updateTTsFirstplanTmpl(tTsFirstplanTmpl));
    }

    /**
     * 删除进组培训模版
     */
    @PreAuthorize("@ss.hasPermi('bccnew:firstPlanTmpl:remove')")
    @Log(title = "进组培训模版", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tTsFirstplanTmplService.deleteTTsFirstplanTmplByIds(ids));
    }

    @Log(title = "附件上传", businessType = BusinessType.UPDATE)
    @PostMapping("/uploadFile/{id}")
    public AjaxResult uploadFile(@RequestParam("file") MultipartFile file, @PathVariable Long id) throws IOException {
        if (!file.isEmpty()) {
            String url = FileUploadUtils.upload(RuoYiConfig.getFilePath("/bccnew"), file);
            TTsFirstplanTmpl entity = tTsFirstplanTmplService.selectTTsFirstplanTmplById(id);
            entity.setFileUrl(url);
            entity.setFileName(file.getOriginalFilename());
            tTsFirstplanTmplService.updateTTsFirstplanTmpl(entity);
            return AjaxResult.success(id);
        }
        return AjaxResult.error("上传失败，请联系管理员");
    }
}
