package com.ruoyi.project.training.bccnew.controller;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.framework.web.page.TableDataInfo;
import com.ruoyi.project.system.domain.SysUser;
import com.ruoyi.project.system.service.ISysUserService;
import com.ruoyi.project.training.bccnew.domain.TTsFlplan;
import com.ruoyi.project.training.bccnew.domain.TTsNew;
import com.ruoyi.project.training.bccnew.service.ITTsApproveService;
import com.ruoyi.project.training.bccnew.service.ITTsFirstplanService;
import com.ruoyi.project.training.bccnew.service.ITTsFlplanService;
import com.ruoyi.project.training.bccnew.service.ITTsNewService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 分离培训Controller
 *
 * @author ssy
 * @date 2024-06-13
 */
@RestController
@RequestMapping("/bccnew/flplandsdt")
public class TTsFlplanController extends BaseController {
    @Autowired
    private ITTsFlplanService tTsFlplanService;
    @Autowired
    private ITTsNewService tTsNewService;
    @Autowired
    private ISysUserService sysUserService;

    @Autowired
    private ITTsFirstplanService tTsFirstplanService;

    @Autowired
    private ITTsApproveService tTsApproveService;

    /**
     * 查询分离培训列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TTsFlplan tTsFlplan) {
        startPage();
        List<TTsFlplan> list = tTsFlplanService.selectTTsFlplanList(tTsFlplan);
        return getDataTable(list);
    }

    /**
     * 导出分离培训列表
     */
    @Log(title = "分离培训", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TTsFlplan tTsFlplan) {
        List<TTsFlplan> list = tTsFlplanService.selectTTsFlplanList(tTsFlplan);
        ExcelUtil<TTsFlplan> util = new ExcelUtil<TTsFlplan>(TTsFlplan.class);
        return util.exportExcel(list, "flplandsdt");
    }

    /**
     * 获取分离培训详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(tTsFlplanService.selectTTsFlplanById(id));
    }

    /**
     * 新增分离培训
     */
    @Log(title = "分离培训", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTsFlplan tTsFlplan) {
        return toAjax(tTsFlplanService.insertTTsFlplan(tTsFlplan));
    }


    @Log(title = "分离培训", businessType = BusinessType.UPDATE)
    @PutMapping("/updateFlLearnTime")
    public AjaxResult updateFlLearnTime(@RequestBody TTsFlplan tTsFlplan) {
        Long userId = getUserId();
        TTsNew tTsNew = tTsNewService.selectTTsNewById(tTsFlplan.getNewId());
        SysUser sysUser = sysUserService.selectUserByStaffId(tTsNew.getStaffId());
        if (userId.equals(sysUser.getUserId())) {
            TTsFlplan need = tTsFlplanService.selectTTsFlplanById(tTsFlplan.getId());
            long timer = need.getTimer() == null ? 0 : need.getTimer();
            need.setTimer(timer + 1);
            if (need.getTimerNeed()==null)
                need.setTimerNeed(0L);
            if (need.getTimerNeed() != null && need.getTimerNeed()<=timer + 1) {
                need.setPlanStatus(2L);
            }
            return toAjax(tTsFlplanService.updateTTsFlplan(need));
        }
        return AjaxResult.error("当前登录用户非学习用户!");
    }

    /**
     * 修改分离培训
     */
    @Log(title = "分离培训", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTsFlplan tTsFlplan) {
        if ("好".equals(tTsFlplan.getScore1())) {
            tTsFlplan.setPlanStatus(5L);
        }
        if ("满意".equals(tTsFlplan.getScore1()) && "好".equals(tTsFlplan.getScore2())) {
            tTsFlplan.setPlanStatus(5L);
        }
        if ("满意".equals(tTsFlplan.getScore1()) && "满意".equals(tTsFlplan.getScore2()) && "好".equals(tTsFlplan.getScore3())) {
            tTsFlplan.setPlanStatus(5L);
        }
        if ("满意".equals(tTsFlplan.getScore1()) && "差".equals(tTsFlplan.getScore2()) && "好".equals(tTsFlplan.getScore2())) {
            tTsFlplan.setPlanStatus(5L);
        }
        if ("差".equals(tTsFlplan.getScore1()) && "好".equals(tTsFlplan.getScore2())) {
            tTsFlplan.setPlanStatus(5L);
        }
        if ("差".equals(tTsFlplan.getScore1()) && "满意".equals(tTsFlplan.getScore2())) {
            tTsFlplan.setPlanStatus(4L);
        }
        if ("差".equals(tTsFlplan.getScore1()) && "差".equals(tTsFlplan.getScore2())) {
            tTsFlplan.setPlanStatus(4L);
        }
        tTsFlplanService.updateTTsFlplan(tTsFlplan);
        if (tTsFlplan.getPlanStatus() == 5) {
            TTsNew tTsNew = new TTsNew();
            tTsNew.setPlanStatus(5L);
            tTsNew.setPlanType(3L);
            tTsNew.setNewId(tTsFlplan.getNewId());
            tTsNewService.updateTTsNew(tTsNew, getUserId(), getNickName());
        } else if (tTsFlplan.getPlanStatus() == 4) {
            TTsNew tTsNew = new TTsNew();
            tTsNew.setPlanStatus(4L);
            tTsNew.setPlanType(3L);
            tTsNew.setNewId(tTsFlplan.getNewId());
            tTsNewService.updateTTsNew(tTsNew, getUserId(), getNickName());
        }
        return AjaxResult.success();
    }

    /**
     * 删除分离培训
     */
    @Log(title = "分离培训", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tTsFlplanService.deleteTTsFlplanByIds(ids));
    }
}
