package com.ruoyi.project.training.bccnew.controller;

import java.io.IOException;
import java.util.List;

import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.framework.config.RuoYiConfig;
import com.ruoyi.project.training.bccnew.domain.TTsFirstplanTmpl;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.training.bccnew.domain.TTsFlplanTmpl;
import com.ruoyi.project.training.bccnew.service.ITTsFlplanTmplService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 分离培训模版Controller
 *
 * @author ssy
 * @date 2024-06-13
 */
@RestController
@RequestMapping("/training/flPlan")
public class TTsFlplanTmplController extends BaseController
{
    @Autowired
    private ITTsFlplanTmplService tTsFlplanTmplService;

    /**
     * 查询分离培训模版列表
     */
    @PreAuthorize("@ss.hasPermi('training:flPlan:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTsFlplanTmpl tTsFlplanTmpl)
    {
        startPage();
        List<TTsFlplanTmpl> list = tTsFlplanTmplService.selectTTsFlplanTmplList(tTsFlplanTmpl);
        return getDataTable(list);
    }

    /**
     * 导出分离培训模版列表
     */
    @PreAuthorize("@ss.hasPermi('training:flPlan:export')")
    @Log(title = "分离培训模版", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TTsFlplanTmpl tTsFlplanTmpl)
    {
        List<TTsFlplanTmpl> list = tTsFlplanTmplService.selectTTsFlplanTmplList(tTsFlplanTmpl);
        ExcelUtil<TTsFlplanTmpl> util = new ExcelUtil<TTsFlplanTmpl>(TTsFlplanTmpl.class);
        return util.exportExcel(list, "flPlan");
    }

    /**
     * 获取分离培训模版详细信息
     */
    @PreAuthorize("@ss.hasPermi('training:flPlan:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tTsFlplanTmplService.selectTTsFlplanTmplById(id));
    }

    /**
     * 新增分离培训模版
     */
    @PreAuthorize("@ss.hasPermi('training:flPlan:add')")
    @Log(title = "分离培训模版", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTsFlplanTmpl tTsFlplanTmpl)
    {
        return toAjax(tTsFlplanTmplService.insertTTsFlplanTmpl(tTsFlplanTmpl));
    }

    /**
     * 修改分离培训模版
     */
    @PreAuthorize("@ss.hasPermi('training:flPlan:edit')")
    @Log(title = "分离培训模版", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTsFlplanTmpl tTsFlplanTmpl)
    {
        return toAjax(tTsFlplanTmplService.updateTTsFlplanTmpl(tTsFlplanTmpl));
    }

    /**
     * 删除分离培训模版
     */
    @PreAuthorize("@ss.hasPermi('training:flPlan:remove')")
    @Log(title = "分离培训模版", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tTsFlplanTmplService.deleteTTsFlplanTmplByIds(ids));
    }

    @Log(title = "附件上传", businessType = BusinessType.UPDATE)
    @PostMapping("/uploadFile")
    public AjaxResult uploadFile(@RequestParam("file") MultipartFile file, Long id) throws IOException {
        if (!file.isEmpty()) {
            String url = FileUploadUtils.upload(RuoYiConfig.getFilePath("/bccnew"), file);
            TTsFlplanTmpl entity = tTsFlplanTmplService.selectTTsFlplanTmplById(id);
            entity.setFileUrl(url);
            entity.setFileName(file.getOriginalFilename());
            tTsFlplanTmplService.updateTTsFlplanTmpl(entity);
            return AjaxResult.success();
        }
        return AjaxResult.error("上传失败，请联系管理员");
    }
}
