package com.ruoyi.project.training.bccnew.controller;

import java.io.IOException;
import java.util.List;

import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.framework.config.RuoYiConfig;
import com.ruoyi.project.training.bccnew.domain.TTsFlplanTmpl;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.training.bccnew.domain.TTsFtplanTmpl;
import com.ruoyi.project.training.bccnew.service.ITTsFtplanTmplService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 芳烃培训模版Controller
 *
 * @author ssy
 * @date 2024-06-13
 */
@RestController
@RequestMapping("/bccnew/ftPlan")
public class TTsFtplanTmplController extends BaseController
{
    @Autowired
    private ITTsFtplanTmplService tTsFtplanTmplService;

    /**
     * 查询芳烃培训模版列表
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ftPlan:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTsFtplanTmpl tTsFtplanTmpl)
    {
        startPage();
        List<TTsFtplanTmpl> list = tTsFtplanTmplService.selectTTsFtplanTmplList(tTsFtplanTmpl);
        return getDataTable(list);
    }

    /**
     * 导出芳烃培训模版列表
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ftPlan:export')")
    @Log(title = "芳烃培训模版", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TTsFtplanTmpl tTsFtplanTmpl)
    {
        List<TTsFtplanTmpl> list = tTsFtplanTmplService.selectTTsFtplanTmplList(tTsFtplanTmpl);
        ExcelUtil<TTsFtplanTmpl> util = new ExcelUtil<TTsFtplanTmpl>(TTsFtplanTmpl.class);
        return util.exportExcel(list, "ftPlan");
    }

    /**
     * 获取芳烃培训模版详细信息
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ftPlan:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tTsFtplanTmplService.selectTTsFtplanTmplById(id));
    }

    /**
     * 新增芳烃培训模版
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ftPlan:add')")
    @Log(title = "芳烃培训模版", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTsFtplanTmpl tTsFtplanTmpl)
    {
        return toAjax(tTsFtplanTmplService.insertTTsFtplanTmpl(tTsFtplanTmpl));
    }

    /**
     * 修改芳烃培训模版
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ftPlan:edit')")
    @Log(title = "芳烃培训模版", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTsFtplanTmpl tTsFtplanTmpl)
    {
        return toAjax(tTsFtplanTmplService.updateTTsFtplanTmpl(tTsFtplanTmpl));
    }

    /**
     * 删除芳烃培训模版
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ftPlan:remove')")
    @Log(title = "芳烃培训模版", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tTsFtplanTmplService.deleteTTsFtplanTmplByIds(ids));
    }

    @Log(title = "附件上传", businessType = BusinessType.UPDATE)
    @PostMapping("/uploadFile")
    public AjaxResult uploadFile(@RequestParam("file") MultipartFile file, Long id) throws IOException {
        if (!file.isEmpty()) {
            String url = FileUploadUtils.upload(RuoYiConfig.getFilePath("/bccnew"), file);
            TTsFtplanTmpl entity = tTsFtplanTmplService.selectTTsFtplanTmplById(id);
            entity.setFileUrl(url);
            entity.setFileName(file.getOriginalFilename());
            tTsFtplanTmplService.updateTTsFtplanTmpl(entity);
            return AjaxResult.success();
        }
        return AjaxResult.error("上传失败，请联系管理员");
    }
}
