package com.ruoyi.project.training.bccnew.controller;

import java.io.IOException;
import java.util.List;

import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.framework.config.RuoYiConfig;
import com.ruoyi.project.training.bccnew.domain.TTsFlplanTmpl;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.training.bccnew.domain.TTsLjplanTmpl;
import com.ruoyi.project.training.bccnew.service.ITTsLjplanTmplService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 裂解培训模版Controller
 *
 * @author ssy
 * @date 2024-06-13
 */
@RestController
@RequestMapping("/bccnew/ljPlan")
public class TTsLjplanTmplController extends BaseController
{
    @Autowired
    private ITTsLjplanTmplService tTsLjplanTmplService;

    /**
     * 查询裂解培训模版列表
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ljPlan:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTsLjplanTmpl tTsLjplanTmpl)
    {
        startPage();
        List<TTsLjplanTmpl> list = tTsLjplanTmplService.selectTTsLjplanTmplList(tTsLjplanTmpl);
        return getDataTable(list);
    }

    /**
     * 导出裂解培训模版列表
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ljPlan:export')")
    @Log(title = "裂解培训模版", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TTsLjplanTmpl tTsLjplanTmpl)
    {
        List<TTsLjplanTmpl> list = tTsLjplanTmplService.selectTTsLjplanTmplList(tTsLjplanTmpl);
        ExcelUtil<TTsLjplanTmpl> util = new ExcelUtil<TTsLjplanTmpl>(TTsLjplanTmpl.class);
        return util.exportExcel(list, "ljPlan");
    }

    /**
     * 获取裂解培训模版详细信息
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ljPlan:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tTsLjplanTmplService.selectTTsLjplanTmplById(id));
    }

    /**
     * 新增裂解培训模版
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ljPlan:add')")
    @Log(title = "裂解培训模版", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTsLjplanTmpl tTsLjplanTmpl)
    {
        return toAjax(tTsLjplanTmplService.insertTTsLjplanTmpl(tTsLjplanTmpl));
    }

    /**
     * 修改裂解培训模版
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ljPlan:edit')")
    @Log(title = "裂解培训模版", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTsLjplanTmpl tTsLjplanTmpl)
    {
        return toAjax(tTsLjplanTmplService.updateTTsLjplanTmpl(tTsLjplanTmpl));
    }

    /**
     * 删除裂解培训模版
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ljPlan:remove')")
    @Log(title = "裂解培训模版", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tTsLjplanTmplService.deleteTTsLjplanTmplByIds(ids));
    }

    @Log(title = "附件上传", businessType = BusinessType.UPDATE)
    @PostMapping("/uploadFile")
    public AjaxResult uploadFile(@RequestParam("file") MultipartFile file, Long id) throws IOException {
        if (!file.isEmpty()) {
            String url = FileUploadUtils.upload(RuoYiConfig.getFilePath("/bccnew"), file);
            TTsLjplanTmpl entity = tTsLjplanTmplService.selectTTsLjplanTmplById(id);
            entity.setFileUrl(url);
            entity.setFileName(file.getOriginalFilename());
            tTsLjplanTmplService.updateTTsLjplanTmpl(entity);
            return AjaxResult.success();
        }
        return AjaxResult.error("上传失败，请联系管理员");
    }
}
