package com.ruoyi.project.training.bccnew.controller;

import java.io.IOException;
import java.util.List;

import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.framework.config.RuoYiConfig;
import com.ruoyi.project.training.bccnew.domain.TTsFlplanTmpl;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.training.bccnew.domain.TTsYsplanTmpl;
import com.ruoyi.project.training.bccnew.service.ITTsYsplanTmplService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 压缩培训模版Controller
 *
 * @author ssy
 * @date 2024-06-13
 */
@RestController
@RequestMapping("/bccnew/ysPlan")
public class TTsYsplanTmplController extends BaseController
{
    @Autowired
    private ITTsYsplanTmplService tTsYsplanTmplService;

    /**
     * 查询压缩培训模版列表
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ysPlan:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTsYsplanTmpl tTsYsplanTmpl)
    {
        startPage();
        List<TTsYsplanTmpl> list = tTsYsplanTmplService.selectTTsYsplanTmplList(tTsYsplanTmpl);
        return getDataTable(list);
    }

    /**
     * 导出压缩培训模版列表
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ysPlan:export')")
    @Log(title = "压缩培训模版", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TTsYsplanTmpl tTsYsplanTmpl)
    {
        List<TTsYsplanTmpl> list = tTsYsplanTmplService.selectTTsYsplanTmplList(tTsYsplanTmpl);
        ExcelUtil<TTsYsplanTmpl> util = new ExcelUtil<TTsYsplanTmpl>(TTsYsplanTmpl.class);
        return util.exportExcel(list, "ysPlan");
    }

    /**
     * 获取压缩培训模版详细信息
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ysPlan:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tTsYsplanTmplService.selectTTsYsplanTmplById(id));
    }

    /**
     * 新增压缩培训模版
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ysPlan:add')")
    @Log(title = "压缩培训模版", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTsYsplanTmpl tTsYsplanTmpl)
    {
        return toAjax(tTsYsplanTmplService.insertTTsYsplanTmpl(tTsYsplanTmpl));
    }

    /**
     * 修改压缩培训模版
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ysPlan:edit')")
    @Log(title = "压缩培训模版", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTsYsplanTmpl tTsYsplanTmpl)
    {
        return toAjax(tTsYsplanTmplService.updateTTsYsplanTmpl(tTsYsplanTmpl));
    }

    /**
     * 删除压缩培训模版
     */
    @PreAuthorize("@ss.hasPermi('bccnew:ysPlan:remove')")
    @Log(title = "压缩培训模版", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tTsYsplanTmplService.deleteTTsYsplanTmplByIds(ids));
    }

    @Log(title = "附件上传", businessType = BusinessType.UPDATE)
    @PostMapping("/uploadFile")
    public AjaxResult uploadFile(@RequestParam("file") MultipartFile file, Long id) throws IOException {
        if (!file.isEmpty()) {
            String url = FileUploadUtils.upload(RuoYiConfig.getFilePath("/bccnew"), file);
            TTsYsplanTmpl entity = tTsYsplanTmplService.selectTTsYsplanTmplById(id);
            entity.setFileUrl(url);
            entity.setFileName(file.getOriginalFilename());
            tTsYsplanTmplService.updateTTsYsplanTmpl(entity);
            return AjaxResult.success();
        }
        return AjaxResult.error("上传失败，请联系管理员");
    }
}
