package com.ruoyi.project.training.controller;

import java.util.List;

import com.ruoyi.project.training.domain.TTrainingbcc;
import com.ruoyi.project.training.service.ITTrainingbccService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.training.domain.TTrainingbccDevice;
import com.ruoyi.project.training.service.ITTrainingbccDeviceService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 人员-装置级培训关系Controller
 *
 * @author ssy
 * @date 2024-06-19
 */
@RestController
@RequestMapping("/training/bccdevice")
public class TTrainingbccDeviceController extends BaseController
{
    @Autowired
    private ITTrainingbccDeviceService tTrainingbccDeviceService;
    @Autowired
    private ITTrainingbccService tTrainingbccService;
    /**
     * 查询人员-装置级培训关系列表
     */
    @PreAuthorize("@ss.hasPermi('training:device:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTrainingbccDevice tTrainingbccDevice)
    {
        startPage();
        List<TTrainingbccDevice> list = tTrainingbccDeviceService.selectTTrainingbccDeviceList(tTrainingbccDevice);
        for (TTrainingbccDevice t: list
             ) {
          TTrainingbcc tTrainingbcc = tTrainingbccService.selectTTrainingbccById(t.getRegularId());
            t.setTrainingbcc(tTrainingbcc);
        }
        return getDataTable(list);
    }

    /**
     * 导出人员-装置级培训关系列表
     */
    @PreAuthorize("@ss.hasPermi('training:device:export')")
    @Log(title = "人员-装置级培训关系", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TTrainingbccDevice tTrainingbccDevice)
    {
        List<TTrainingbccDevice> list = tTrainingbccDeviceService.selectTTrainingbccDeviceList(tTrainingbccDevice);
        ExcelUtil<TTrainingbccDevice> util = new ExcelUtil<TTrainingbccDevice>(TTrainingbccDevice.class);
        return util.exportExcel(list, "device");
    }

    /**
     * 获取人员-装置级培训关系详细信息
     */
    @PreAuthorize("@ss.hasPermi('training:device:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tTrainingbccDeviceService.selectTTrainingbccDeviceById(id));
    }

    /**
     * 新增人员-装置级培训关系
     */
    @PreAuthorize("@ss.hasPermi('training:device:add')")
    @Log(title = "人员-装置级培训关系", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTrainingbccDevice tTrainingbccDevice)
    {
        return toAjax(tTrainingbccDeviceService.insertTTrainingbccDevice(tTrainingbccDevice));
    }

    /**
     * 修改人员-装置级培训关系
     */
    @PreAuthorize("@ss.hasPermi('training:device:edit')")
    @Log(title = "人员-装置级培训关系", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTrainingbccDevice tTrainingbccDevice)
    {

        return toAjax(tTrainingbccDeviceService.updateTTrainingbccDevice(tTrainingbccDevice));
    }

    @PutMapping("/updateDeviceLearnTime")
    @Log(title = "人员-装置级培训-更新时长", businessType = BusinessType.UPDATE)
    public AjaxResult updateDeviceLearnTime(@RequestBody TTrainingbccDevice tTrainingbccDevice)
    {

        TTrainingbccDevice t=   tTrainingbccDeviceService.selectTTrainingbccDeviceById(tTrainingbccDevice.getId());
        TTrainingbcc tTrainingbcc = tTrainingbccService.selectTTrainingbccById(t.getRegularId());
        t.setLearnTime(t.getLearnTime() +1);
        if (tTrainingbcc.getTimerNeed() != null && tTrainingbcc.getTimerNeed() < t.getLearnTime()) {
            t.setLearnState(1l);
        }
        return toAjax(tTrainingbccDeviceService.updateTTrainingbccDevice(t));
    }

    /**
     * 删除人员-装置级培训关系
     */
    @PreAuthorize("@ss.hasPermi('training:device:remove')")
    @Log(title = "人员-装置级培训关系", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tTrainingbccDeviceService.deleteTTrainingbccDeviceByIds(ids));
    }
}
