package com.ruoyi.project.training.controller;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import com.ruoyi.project.plant.domain.TStaffmgr;
import com.ruoyi.project.plant.service.ITStaffmgrService;
import com.ruoyi.project.system.domain.SysDictData;
import com.ruoyi.project.system.service.ISysDictTypeService;
import com.ruoyi.project.training.domain.*;
import com.ruoyi.project.training.service.ITTrainingService;
import com.ruoyi.project.training.service.ITTrainingbccDeviceService;
import com.ruoyi.project.training.service.ITTrainingbccService;
import org.apache.commons.lang.StringUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.training.service.ITTrainingbccRegularService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 装置培训计划Controller
 *
 * @author ssy
 * @date 2024-06-24
 */
@RestController
@RequestMapping("/training/bccregular")
public class TTrainingbccRegularController extends BaseController
{
    @Autowired
    private ITTrainingbccRegularService tTrainingbccRegularService;
    @Autowired
    private ISysDictTypeService iSysDictTypeService;
    @Autowired
    private ITTrainingbccService trainingbccService;

    @Autowired
    private ITTrainingbccDeviceService trainingbccDeviceService;

    @Autowired
    private ITStaffmgrService tStaffmgrService;
    /**
     * 查询装置培训计划列表
     */
    @PreAuthorize("@ss.hasPermi('training:bccregular:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTrainingbccRegular tTrainingRegular)
    {
        startPage();
        List<TTrainingbccRegular> list = tTrainingbccRegularService.selectTTrainingbccRegularList(tTrainingRegular);
        List<SysDictData> actualpost = iSysDictTypeService.selectDictDataByType("ACTUALPOST");
        for (TTrainingbccRegular t : list) {
            String[] actualpostId = new String[0];;
            if (t.getActualpostId() != null) {
                actualpostId = t.getActualpostId().split(",");
            }
            List<String> postStatu = new ArrayList<>();
            for (SysDictData p : actualpost) {
                int i = 0;
                for (String a : actualpostId) {
                    if (p.getDictValue().equals(a)) {
                        i = 1;
                    }
                }
                if (t.getDesignatedPosition() != null) {
                    String[] designatedPosition = t.getDesignatedPosition().split(",");
                    for (String d : designatedPosition) {
                        if (p.getDictValue().equals(d)) {
                            i = 2;
                        }
                    }
                }
                if (i == 1) {
                    postStatu.add("M");
                }else if (i == 2) {
                    postStatu.add("|");
                }else {
                    postStatu.add("-");
                }
            }
            if (t.getInvolvedMoc().equals("true")) {
                if (t.getDesignatedOther() != null) {
                    String[] designatedOther = t.getDesignatedOther().split(",");
                    for (String d : designatedOther) {
                        if (d.equals("28")) {
                            postStatu.set(postStatu.size() - 5, "(M)");
                        }
                        if (d.equals("30")) {
                            postStatu.set(postStatu.size() - 4, "(M)");
                        }
                        if (d.equals("32")) {
                            postStatu.set(postStatu.size() - 3, "(M)");
                        }
                    }
                }
            }
            t.setActualpost(postStatu);
        }
        return getDataTable(list);
    }

    /**
     * 导出装置培训计划列表
     */
    @PreAuthorize("@ss.hasPermi('training:bccregular:export')")
    @Log(title = "装置培训计划", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TTrainingbccRegular tTrainingbccRegular)
    {
        List<TTrainingbccRegular> list = tTrainingbccRegularService.selectTTrainingbccRegularList(tTrainingbccRegular);
        ExcelUtil<TTrainingbccRegular> util = new ExcelUtil<TTrainingbccRegular>(TTrainingbccRegular.class);
        return util.exportExcel(list, "bccregular");
    }

    /**
     * 获取装置培训计划详细信息
     */
    @PreAuthorize("@ss.hasPermi('training:bccregular:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tTrainingbccRegularService.selectTTrainingbccRegularById(id));
    }

    /**
     * 新增装置培训计划
     */
    @PreAuthorize("@ss.hasPermi('training:bccregular:add')")
    @Log(title = "装置培训计划", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTrainingbccRegular tTrainingRegular)
    {
        int doInsert = tTrainingbccRegularService.insertTTrainingbccRegular(tTrainingRegular);
        logger.info("regular:" + tTrainingRegular);
        //如果确定计划日期新增关联内容
        if (tTrainingRegular.getNotPlan().equals("true")) {
            //新增培训计划定期类
            TTrainingbcc tTraining = new TTrainingbcc();
            tTraining.setTrainingType("10");
            tTraining.setYears(tTrainingRegular.getYear());
            tTraining.setCourse(tTrainingRegular.getItem());
            tTraining.setCourseid(tTrainingRegular.getCourseCode());
            tTraining.setDuration(tTrainingRegular.getHour());
            tTraining.setTrainer(tTrainingRegular.getLecturer());
            tTraining.setPosition(tTrainingRegular.getActualpostId());
            tTraining.setIsfinish(Long.parseLong("0"));
            tTraining.setDeptId(tTrainingRegular.getDeptId());
            tTraining.setRegularId(tTrainingRegular.getId());
            trainingbccService.insertTTrainingbcc(tTraining);
            Long trainingId = tTraining.getId();
            //新增人员-装置级关系
            // 参培岗位人员
            if (tTrainingRegular.getActualpostId() != null) {
                logger.info("参培岗位人员");
                TStaffmgr staffmgr = new TStaffmgr();
                staffmgr.setActualposts(tTrainingRegular.getActualpostId());
                List<TStaffmgr> staffmgrs = tStaffmgrService.selectAllTStaffmgrList(staffmgr);
                try {
                    //判断离职
                    if (!StringUtils.isEmpty(tTrainingRegular.getYear())) {
                        Iterator<TStaffmgr> iterator = staffmgrs.iterator();
                        while (iterator.hasNext()) {
                            TStaffmgr t = iterator.next();
                            if (t.getLeftDate() != null && t.getDelFlag() == 9){
                                if (t.getLeftDate().getTime() - tTrainingRegular.getPlanTrainingdate().getTime() < 0l ) {
                                    logger.debug(t.getName() + "离职时间小于培训时间");
                                    iterator.remove();
                                }
                            }
                        }
                    }
                }catch (Exception e) {
                    logger.error(e.toString());
                }
                for (TStaffmgr s : staffmgrs) {
                    TTrainingbccDevice tTrainingDevice = new TTrainingbccDevice();
                    tTrainingDevice.setStaffId(s.getStaffid());
                    tTrainingDevice.setRegularId(trainingId);
                    tTrainingDevice.setStartDate(tTrainingRegular.getPlanTrainingdate());
                    tTrainingDevice.setSupplementary("0");
                    trainingbccDeviceService.insertTTrainingbccDevice(tTrainingDevice);
                }
            }
            //指定岗位人员
            if (tTrainingRegular.getDesignatedStaff() != null) {
                logger.info("指定岗位人员");
                String[] designatedStaffs = tTrainingRegular.getDesignatedStaff().split(",");
                for (String staffId : designatedStaffs) {
                    TTrainingbccDevice tTrainingDevice = new TTrainingbccDevice();
                    tTrainingDevice.setStaffId(staffId);
                    tTrainingDevice.setRegularId(trainingId);
                    tTrainingDevice.setStartDate(tTrainingRegular.getPlanTrainingdate());
                    tTrainingDevice.setSupplementary("0");
                    trainingbccDeviceService.insertTTrainingbccDevice(tTrainingDevice);
                }
            }
            //涉及其他部门
            if (tTrainingRegular.getInvolvedMoc().equals("true")){
                logger.info("涉及MOC人员");
                TStaffmgr staffmgrMoc = new TStaffmgr();
                staffmgrMoc.setActualposts(tTrainingRegular.getDesignatedOther());
                List<TStaffmgr> staffmgrsMoc = tStaffmgrService.selectAllTStaffmgrList(staffmgrMoc);
                try {
                    //判断离职
                    if (!StringUtils.isEmpty(tTrainingRegular.getYear())) {
                        Iterator<TStaffmgr> iterator = staffmgrsMoc.iterator();
                        while (iterator.hasNext()) {
                            TStaffmgr t = iterator.next();
                            if (t.getLeftDate() != null && t.getDelFlag() == 9){
                                if (t.getLeftDate().getTime() - tTrainingRegular.getPlanTrainingdate().getTime() > 0l ) {
                                    logger.debug(t.getName() + "离职时间小于培训时间");
                                    iterator.remove();
                                }
                            }
                        }
                    }
                }catch (Exception e) {
                    logger.error(e.toString());
                }
                for (TStaffmgr s : staffmgrsMoc) {
                    TTrainingbccDevice tTrainingDevice = new TTrainingbccDevice();
                    tTrainingDevice.setStaffId(s.getStaffid());
                    tTrainingDevice.setRegularId(trainingId);
                    tTrainingDevice.setStartDate(tTrainingRegular.getPlanTrainingdate());
                    tTrainingDevice.setSupplementary("0");
                    trainingbccDeviceService.insertTTrainingbccDevice(tTrainingDevice);
                }
            }
        }
        return toAjax(doInsert);
    }

    /**
     * 修改装置培训计划
     */
    @PreAuthorize("@ss.hasPermi('training:bccregular:edit')")
    @Log(title = "装置培训计划", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTrainingbccRegular tTrainingbccRegular)
    {
        return toAjax(tTrainingbccRegularService.updateTTrainingbccRegular(tTrainingbccRegular));
    }

    /**
     * 删除装置培训计划
     */
    @PreAuthorize("@ss.hasPermi('training:bccregular:remove')")
    @Log(title = "装置培训计划", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tTrainingbccRegularService.deleteTTrainingbccRegularByIds(ids));
    }
}
